/*
** Copyright 1998 - 1999 Double Precision, Inc.  See COPYING for
** distribution information.
*/

#include	"auth.h"
#include	"authstaticlist.h"
#include	"authsasl.h"
#include	<stdio.h>

static const char rcsid[]="$Id: authinfo.c,v 1.4 2000/04/26 22:32:37 mrsam Exp $";

int main()
{
int	i;

	printf("AUTHENTICATION_MODULES=\"");
	for (i=0; authstaticlist[i].auth_name; i++)
		printf("%s%s", i ? " ":"", authstaticlist[i].auth_name);
	printf("\"\n");
#ifdef	AUTHDAEMONMODULELIST
	printf("AUTHDAEMONMODULELIST=\"%s\"\n",
		AUTHDAEMONMODULELIST);
#endif
	printf("SASL_AUTHENTICATION_MODULES=\"");
	for (i=0; authsasl_list[i].sasl_method; i++)
		printf("%s%s", i ? " ":"", authsasl_list[i].sasl_method);
	printf("\"\n");
	return (0);
}
